.. _label_api_overview:

Overview
========

API documentation for squidasm.
Many of the objects used for application writing are from the NetQASM SDK.
These objects have their documentation on `NETQASM SDK documentation <https://netqasm.readthedocs.io/en/latest/netqasm.sdk.html>`_.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    modules/configurations
    modules/simulation_run
    modules/logger
    modules/program
    modules/classical_socket



